"""
    Utilisation des fichiers .csv en Python:
    Voir https://docs.python.org/3/library/csv.html
"""
import csv

# numéro de ticket que l' on souhaite imprimer
NUM_TICKET = "7193"

# Liste des achats correspondants au ticket
liste_achats = []

# On  parcourt la table des achats pour récupérer 
# la liste des produits correspondants au ticket
#
# table acheter_produit: NumTicket , CodeProduit, Quantite
with open(
    "table_acheter_produit.csv", encoding="utf-8"
) as fichier_table_acheter_produit:
    table_acheter_produit = csv.DictReader(fichier_table_acheter_produit, delimiter=";")
    for achat in table_acheter_produit:
        # on garde les achats correspondants au numéro du ticket
        if achat["NumTicket"] == NUM_TICKET:
            liste_achats.append(achat)


# On récupère le nom, le prix, le code catégorie et la disponnibilité 
# en stock de chaque produit de la liste achetée, grace à la 
# table des produits. 
# On complète chaque achat avec les informations supplémentaires
# table_produit.csv: CodeProduit, NomProduit, PrixTTC, CodeCategorie, EnStock(O/N)

with open("table_produit.csv", encoding="utf-8") as fichier_table_produit:
    table_produit = csv.DictReader(fichier_table_produit, delimiter=";")
    for produit in table_produit:
        for achat in liste_achats:
            code = achat["CodeProduit"]
            # on a trouvé le code produit d'un achat de notre liste, on
            # va ajouter les informations supplémentaires qui nous manquent
            if produit["CodeProduit"] == code:
                achat["NomProduit"] = produit["NomProduit"]
                achat["CodeCategorie"] = produit["CodeCategorie"]
                achat["PrixTTC"] = produit["PrixTTC"]


# On imprime le ticket de caisse, avec toutes les informations
# récoltées dans la table des produits achetés et la table
# des produits.
# L'affichage est formaté grâce aux f-strings en Python
# Voir https://fstring.help/cheat/ pour toutes les options de formatage

titre_ticket = f'{"Ticket n°"+NUM_TICKET:-^39}'
print(titre_ticket)
print(f'{"":*^39}')
print(f'|{"Nom":<16}|{"Prix":>5}|{"Qté":>3}|{"Montant":>10}|')
print(f'{"":*^39}')
TOTAL = 0.0
for a in liste_achats:
    prix = float(a["PrixTTC"])
    qte = float(a["Quantite"])
    montant = qte * prix
    TOTAL = TOTAL + montant
    print(
        f'|{a["NomProduit"]:<16}|{a["PrixTTC"]:>5}|{ a["Quantite"]:>3}|{montant:>10.2f}|'
    )
print(f'{"":=^39}')
print(f"|Total : {TOTAL: >29.2f}|")
print(f'{"":*^39}')
print("\nLa maison ne fait pas crédit.")
